@@ -814,7 +814,7 @@ color_sample_draw_sample (GtkColorSelection *colorsel, int which)
   priv = colorsel->private_data;
   
   g_return_if_fail (priv->sample_area != NULL);
-  if (!GTK_WIDGET_DRAWABLE (priv->sample_area))
+  if (!gtk_widget_is_drawable (priv->sample_area))
     return;
 
   if (which == 0)
@@ -945,6 +945,30 @@ color_sample_setup_dnd (GtkColorSelection *colorsel, GtkWidget *sample)
   
 }
 
+static void
+update_tooltips (GtkColorSelection *colorsel)
+{
+  ColorSelectionPrivate *priv;
+
+  priv = colorsel->private_data;
+
+  if (priv->has_palette == TRUE)
+    {
+      gtk_widget_set_tooltip_text (priv->old_sample,
+                            _("The previously-selected color, for comparison to the color you're selecting now. You can drag this color to a palette entry, or select this color as current by dragging it to the other color swatch alongside."));
+
+      gtk_widget_set_tooltip_text (priv->cur_sample,
+                            _("The color you've chosen. You can drag this color to a palette entry to save it for use in the future."));
+    }
+  else
+    {
+      gtk_widget_set_tooltip_text (priv->old_sample,
+                            _("The previously-selected color, for comparison to the color you're selecting now."));
+
+      gtk_widget_set_tooltip_text (priv->cur_sample,
+                            _("The color you've chosen."));
+    }
+}
 
 static void
 color_sample_new (GtkColorSelection *colorsel)
@@ -972,13 +996,8 @@ color_sample_new (GtkColorSelection *colorsel)
   color_sample_setup_dnd (colorsel, priv->old_sample);
   color_sample_setup_dnd (colorsel, priv->cur_sample);
 
-  gtk_widget_set_tooltip_text (priv->old_sample,
-                        _("The previously-selected color, for comparison to the color you're selecting now. You can drag this color to a palette entry, or select this color as current by dragging it to the other color swatch alongside."));
+  update_tooltips (colorsel);
 
-
-  gtk_widget_set_tooltip_text (priv->cur_sample,
-                        _("The color you've chosen. You can drag this color to a palette entry to save it for use in the future."));
-  
   gtk_widget_show_all (priv->sample_area);
 }
 
@@ -1030,7 +1049,7 @@ palette_paint (GtkWidget    *drawing_area,
   gdk_cairo_rectangle (cr, area);
   cairo_fill (cr);
   
-  if (GTK_WIDGET_HAS_FOCUS (drawing_area))
+  if (gtk_widget_has_focus (drawing_area))
     {
       set_focus_line_attributes (drawing_area, cr, &focus_width);
 
@@ -1312,7 +1331,7 @@ popup_position_func (GtkMenu   *menu,
   
   widget = GTK_WIDGET (user_data);
   
-  g_return_if_fail (GTK_WIDGET_REALIZED (widget));
+  g_return_if_fail (gtk_widget_get_realized (widget));
 
   gdk_window_get_origin (widget->window, &root_x, &root_y);
   
@@ -1528,7 +1547,7 @@ palette_new (GtkColorSelection *colorsel)
   
   retval = gtk_drawing_area_new ();
 
-  GTK_WIDGET_SET_FLAGS (retval, GTK_CAN_FOCUS);
+  gtk_widget_set_can_focus (retval, TRUE);
   
   g_object_set_data (G_OBJECT (retval), I_("color_set"), GINT_TO_POINTER (0)); 
   gtk_widget_set_events (retval, GDK_BUTTON_PRESS_MASK
@@ -2251,14 +2270,6 @@ gtk_color_selection_new (void)
   return GTK_WIDGET (colorsel);
 }
 
-
-void
-gtk_color_selection_set_update_policy (GtkColorSelection *colorsel,
-				       GtkUpdateType      policy)
-{
-  g_return_if_fail (GTK_IS_COLOR_SELECTION (colorsel));
-}
-
 /**
  * gtk_color_selection_get_has_opacity_control:
  * @colorsel: a #GtkColorSelection.
@@ -2364,7 +2375,9 @@ gtk_color_selection_set_has_palette (GtkColorSelection *colorsel,
 	gtk_widget_show (priv->palette_frame);
       else
 	gtk_widget_hide (priv->palette_frame);
-      
+
+      update_tooltips (colorsel);
+
       g_object_notify (G_OBJECT (colorsel), "has-palette");
     }
 }
@@ -2436,26 +2449,6 @@ gtk_color_selection_set_current_alpha (GtkColorSelection *colorsel,
   update_color (colorsel);
 }
 
-/**
- * gtk_color_selection_set_color:
- * @colorsel: a #GtkColorSelection.
- * @color: an array of 4 doubles specifying the red, green, blue and opacity 
- *   to set the current color to.
- *
- * Sets the current color to be @color.  The first time this is called, it will
- * also set the original color to be @color too.
- *
- * Deprecated: 2.0: Use gtk_color_selection_set_current_color() instead.
- **/
-void
-gtk_color_selection_set_color (GtkColorSelection    *colorsel,
-			       gdouble              *color)
-{
-  g_return_if_fail (GTK_IS_COLOR_SELECTION (colorsel));
-
-  set_color_internal (colorsel, color);
-}
-
 /**
  * gtk_color_selection_get_current_color:
  * @colorsel: a #GtkColorSelection.
@@ -2497,30 +2490,6 @@ gtk_color_selection_get_current_alpha (GtkColorSelection *colorsel)
   return priv->has_opacity ? UNSCALE (priv->color[COLORSEL_OPACITY]) : 65535;
 }
 
-/**
- * gtk_color_selection_get_color:
- * @colorsel: a #GtkColorSelection.
- * @color: an array of 4 #gdouble to fill in with the current color.
- *
- * Sets @color to be the current color in the GtkColorSelection widget.
- *
- * Deprecated: Use gtk_color_selection_get_current_color() instead.
- **/
-void
-gtk_color_selection_get_color (GtkColorSelection *colorsel,
-			       gdouble           *color)
-{
-  ColorSelectionPrivate *priv;
-  
-  g_return_if_fail (GTK_IS_COLOR_SELECTION (colorsel));
-  
-  priv = colorsel->private_data;
-  color[0] = priv->color[COLORSEL_RED];
-  color[1] = priv->color[COLORSEL_GREEN];
-  color[2] = priv->color[COLORSEL_BLUE];
-  color[3] = priv->has_opacity ? priv->color[COLORSEL_OPACITY] : 65535;
-}
-
 /**
  * gtk_color_selection_set_previous_color:
  * @colorsel: a #GtkColorSelection.
@@ -2809,33 +2778,6 @@ gtk_color_selection_palette_to_string (const GdkColor *colors,
   return retval;
 }
 
-/**
- * gtk_color_selection_set_change_palette_hook:
- * @func: a function to call when the custom palette needs saving.
- * 
- * Installs a global function to be called whenever the user tries to
- * modify the palette in a color selection. This function should save
- * the new palette contents, and update the GtkSettings property
- * "gtk-color-palette" so all GtkColorSelection widgets will be modified.
- *
- * Return value: the previous change palette hook (that was replaced).
- *
- * Deprecated: 2.4: This function does not work in multihead environments.
- *     Use gtk_color_selection_set_change_palette_with_screen_hook() instead. 
- * 
- **/
-GtkColorSelectionChangePaletteFunc
-gtk_color_selection_set_change_palette_hook (GtkColorSelectionChangePaletteFunc func)
-{
-  GtkColorSelectionChangePaletteFunc old;
-
-  old = noscreen_change_palette_hook;
-
-  noscreen_change_palette_hook = func;
-
-  return old;
-}
-
 /**
  * gtk_color_selection_set_change_palette_with_screen_hook:
  * @func: a function to call when the custom palette needs saving.
