@@ -181,14 +181,13 @@ file_chooser_widget_default_size_changed (GtkWidget            *widget,
   GtkFileChooserDialogPrivate *priv;
   gint default_width, default_height;
   GtkRequisition req, widget_req;
-  int xpos, ypos;
 
   priv = GTK_FILE_CHOOSER_DIALOG_GET_PRIVATE (dialog);
 
   /* Unset any previously set size */
   gtk_widget_set_size_request (GTK_WIDGET (dialog), -1, -1);
 
-  if (GTK_WIDGET_DRAWABLE (widget))
+  if (gtk_widget_is_drawable (widget))
     {
       /* Force a size request of everything before we start.  This will make sure
        * that widget->requisition is meaningful. */
@@ -201,7 +200,7 @@ file_chooser_widget_default_size_changed (GtkWidget            *widget,
 
   gtk_window_resize (GTK_WINDOW (dialog), default_width, default_height);
 
-  if (!GTK_WIDGET_MAPPED (dialog))
+  if (!gtk_widget_get_mapped (GTK_WIDGET (dialog)))
     {
 #if 0
       /* FIXME: the code to restore the position does not work yet.  It is not
@@ -273,7 +272,6 @@ gtk_file_chooser_dialog_constructor (GType                  type,
 
   if (priv->file_system)
     priv->widget = g_object_new (GTK_TYPE_FILE_CHOOSER_WIDGET,
-				 "file-system-backend", priv->file_system,
 				 NULL);
   else
     priv->widget = g_object_new (GTK_TYPE_FILE_CHOOSER_WIDGET, NULL);
@@ -309,10 +307,6 @@ gtk_file_chooser_dialog_set_property (GObject         *object,
 
   switch (prop_id)
     {
-    case GTK_FILE_CHOOSER_PROP_FILE_SYSTEM_BACKEND:
-      g_free (priv->file_system);
-      priv->file_system = g_value_dup_string (value);
-      break;
     default:
       g_object_set_property (G_OBJECT (priv->widget), pspec->name, value);
       break;
@@ -359,7 +353,7 @@ gtk_file_chooser_dialog_map (GtkWidget *widget)
 
   ensure_default_response (dialog);
 
-  if (!GTK_WIDGET_MAPPED (priv->widget))
+  if (!gtk_widget_get_mapped (priv->widget))
     gtk_widget_map (priv->widget);
 
   _gtk_file_chooser_embed_initial_focus (GTK_FILE_CHOOSER_EMBED (priv->widget));
@@ -409,7 +403,6 @@ static GtkWidget *
 gtk_file_chooser_dialog_new_valist (const gchar          *title,
 				    GtkWindow            *parent,
 				    GtkFileChooserAction  action,
-				    const gchar          *backend,
 				    const gchar          *first_button_text,
 				    va_list               varargs)
 {
@@ -437,10 +430,10 @@ gtk_file_chooser_dialog_new_valist (const gchar          *title,
 
 /**
  * gtk_file_chooser_dialog_new:
- * @title: Title of the dialog, or %NULL
- * @parent: Transient parent of the dialog, or %NULL
+ * @title: (allow-none): Title of the dialog, or %NULL
+ * @parent: (allow-none): Transient parent of the dialog, or %NULL
  * @action: Open or save mode for the dialog
- * @first_button_text: stock ID or text to go in the first button, or %NULL
+ * @first_button_text: (allow-none): stock ID or text to go in the first button, or %NULL
  * @Varargs: response ID for the first button, then additional (button, id) pairs, ending with %NULL
  *
  * Creates a new #GtkFileChooserDialog.  This function is analogous to
@@ -462,46 +455,7 @@ gtk_file_chooser_dialog_new (const gchar         *title,
   
   va_start (varargs, first_button_text);
   result = gtk_file_chooser_dialog_new_valist (title, parent, action,
-					       NULL, first_button_text,
-					       varargs);
-  va_end (varargs);
-
-  return result;
-}
-
-/**
- * gtk_file_chooser_dialog_new_with_backend:
- * @title: Title of the dialog, or %NULL
- * @parent: Transient parent of the dialog, or %NULL
- * @action: Open or save mode for the dialog
- * @backend: The name of the specific filesystem backend to use.
- * @first_button_text: stock ID or text to go in the first button, or %NULL
- * @Varargs: response ID for the first button, then additional (button, id) pairs, ending with %NULL
- *
- * Creates a new #GtkFileChooserDialog with a specified backend. This is
- * especially useful if you use gtk_file_chooser_set_local_only() to allow
- * non-local files and you use a more expressive vfs, such as gnome-vfs,
- * to load files.
- *
- * Return value: a new #GtkFileChooserDialog
- *
- * Since: 2.4
- * Deprecated: 2.14
- **/
-GtkWidget *
-gtk_file_chooser_dialog_new_with_backend (const gchar          *title,
-					  GtkWindow            *parent,
-					  GtkFileChooserAction  action,
-					  const gchar          *backend,
-					  const gchar          *first_button_text,
-					  ...)
-{
-  GtkWidget *result;
-  va_list varargs;
-  
-  va_start (varargs, first_button_text);
-  result = gtk_file_chooser_dialog_new_valist (title, parent, action,
-					       backend, first_button_text,
+					       first_button_text,
 					       varargs);
   va_end (varargs);
 
