@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -128,8 +128,6 @@ void       gtk_message_dialog_format_secondary_markup (GtkMessageDialog *message
                                                        const gchar      *message_format,
                                                        ...) G_GNUC_PRINTF (2, 3);
 
-GtkWidget *gtk_message_dialog_get_message_area (GtkMessageDialog *message_dialog);
-
 G_END_DECLS
 
 #endif /* __GTK_MESSAGE_DIALOG_H__ */
