@@ -25,6 +25,7 @@
 *tp++ = gdk_font_get_type();
 *tp++ = gdk_font_type_get_type();
 *tp++ = gdk_function_get_type();
+*tp++ = gdk_gc_get_type();
 *tp++ = gdk_gc_values_mask_get_type();
 *tp++ = gdk_grab_status_get_type();
 *tp++ = gdk_gravity_get_type();
@@ -46,7 +47,6 @@
 *tp++ = gdk_pixbuf_animation_get_type();
 *tp++ = gdk_pixbuf_animation_iter_get_type();
 *tp++ = gdk_pixbuf_error_get_type();
-*tp++ = gdk_pixbuf_format_get_type();
 *tp++ = gdk_pixbuf_get_type();
 *tp++ = gdk_pixbuf_loader_get_type();
 *tp++ = gdk_pixbuf_rotation_get_type();
@@ -87,7 +87,6 @@
 *tp++ = gtk_adjustment_get_type();
 *tp++ = gtk_alignment_get_type();
 *tp++ = gtk_anchor_type_get_type();
-*tp++ = gtk_arg_flags_get_type();
 *tp++ = gtk_arrow_get_type();
 *tp++ = gtk_arrow_placement_get_type();
 *tp++ = gtk_arrow_type_get_type();
@@ -101,7 +100,6 @@
 *tp++ = gtk_buildable_get_type();
 *tp++ = gtk_builder_error_get_type();
 *tp++ = gtk_builder_get_type();
-*tp++ = gtk_button_action_get_type();
 *tp++ = gtk_button_box_get_type();
 *tp++ = gtk_button_box_style_get_type();
 *tp++ = gtk_button_get_type();
@@ -122,24 +120,17 @@
 *tp++ = gtk_cell_renderer_state_get_type();
 *tp++ = gtk_cell_renderer_text_get_type();
 *tp++ = gtk_cell_renderer_toggle_get_type();
-*tp++ = gtk_cell_type_get_type();
 *tp++ = gtk_cell_view_get_type();
 *tp++ = gtk_check_button_get_type();
 *tp++ = gtk_check_menu_item_get_type();
 *tp++ = gtk_clipboard_get_type();
-*tp++ = gtk_clist_drag_pos_get_type();
 *tp++ = gtk_color_button_get_type();
 *tp++ = gtk_color_selection_dialog_get_type();
 *tp++ = gtk_color_selection_get_type();
+*tp++ = gtk_combo_box_entry_get_type();
 *tp++ = gtk_combo_box_get_type();
-*tp++ = gtk_combo_box_text_get_type();
 *tp++ = gtk_container_get_type();
 *tp++ = gtk_corner_type_get_type();
-*tp++ = gtk_ctree_expander_style_get_type();
-*tp++ = gtk_ctree_expansion_type_get_type();
-*tp++ = gtk_ctree_line_style_get_type();
-*tp++ = gtk_ctree_pos_get_type();
-*tp++ = gtk_curve_type_get_type();
 *tp++ = gtk_debug_flag_get_type();
 *tp++ = gtk_delete_type_get_type();
 *tp++ = gtk_dest_defaults_get_type();
@@ -156,6 +147,7 @@
 *tp++ = gtk_event_box_get_type();
 *tp++ = gtk_expander_get_type();
 *tp++ = gtk_expander_style_get_type();
+*tp++ = gtk_extended_layout_get_type();
 *tp++ = gtk_file_chooser_action_get_type();
 *tp++ = gtk_file_chooser_button_get_type();
 *tp++ = gtk_file_chooser_confirmation_get_type();
@@ -206,7 +198,6 @@
 *tp++ = gtk_layout_get_type();
 *tp++ = gtk_link_button_get_type();
 *tp++ = gtk_list_store_get_type();
-*tp++ = gtk_match_type_get_type();
 *tp++ = gtk_menu_bar_get_type();
 *tp++ = gtk_menu_direction_type_get_type();
 *tp++ = gtk_menu_get_type();
@@ -239,7 +230,6 @@
 *tp++ = gtk_plug_get_type();
 *tp++ = gtk_policy_type_get_type();
 *tp++ = gtk_position_type_get_type();
-*tp++ = gtk_preview_type_get_type();
 *tp++ = gtk_print_context_get_type();
 *tp++ = gtk_print_duplex_get_type();
 *tp++ = gtk_print_error_get_type();
@@ -251,6 +241,7 @@
 *tp++ = gtk_print_quality_get_type();
 *tp++ = gtk_print_settings_get_type();
 *tp++ = gtk_print_status_get_type();
+*tp++ = gtk_private_flags_get_type();
 *tp++ = gtk_progress_bar_get_type();
 *tp++ = gtk_progress_bar_orientation_get_type();
 *tp++ = gtk_progress_bar_style_get_type();
@@ -293,8 +284,6 @@
 *tp++ = gtk_separator_tool_item_get_type();
 *tp++ = gtk_settings_get_type();
 *tp++ = gtk_shadow_type_get_type();
-*tp++ = gtk_side_type_get_type();
-*tp++ = gtk_signal_run_type_get_type();
 *tp++ = gtk_size_group_get_type();
 *tp++ = gtk_size_group_mode_get_type();
 *tp++ = gtk_socket_get_type();
@@ -318,7 +307,6 @@
 *tp++ = gtk_text_buffer_target_info_get_type();
 *tp++ = gtk_text_child_anchor_get_type();
 *tp++ = gtk_text_direction_get_type();
-*tp++ = gtk_text_get_type();
 *tp++ = gtk_text_iter_get_type();
 *tp++ = gtk_text_mark_get_type();
 *tp++ = gtk_text_search_flags_get_type();
@@ -342,8 +330,6 @@
 *tp++ = gtk_tooltip_get_type();
 *tp++ = gtk_tree_drag_dest_get_type();
 *tp++ = gtk_tree_drag_source_get_type();
-*tp++ = gtk_tree_get_type();
-*tp++ = gtk_tree_item_get_type();
 *tp++ = gtk_tree_iter_get_type();
 *tp++ = gtk_tree_model_filter_get_type();
 *tp++ = gtk_tree_model_flags_get_type();
@@ -359,7 +345,6 @@
 *tp++ = gtk_tree_view_drop_position_get_type();
 *tp++ = gtk_tree_view_get_type();
 *tp++ = gtk_tree_view_grid_lines_get_type();
-*tp++ = gtk_tree_view_mode_get_type();
 *tp++ = gtk_ui_manager_get_type();
 *tp++ = gtk_ui_manager_item_type_get_type();
 *tp++ = gtk_unit_get_type();
